@@ -11,9 +11,9 @@ class IAMPolicyFinderTest(unittest.TestCase):
 
     def test_file_path(self):
         """Tests the path is correct."""
-        finder = IAMPolicyFinder('/')
-        file_path = finder.file_path('my_test')
-        self.assertEqual(file_path, '/test_my_test/policies.yaml')
+        finder = IAMPolicyFinder("/")
+        file_path = finder.file_path("my_test")
+        self.assertEqual(file_path, "/test_my_test/policies.yaml")
 
 
 class IAMPolicyBuilderTest(unittest.TestCase):
@@ -21,15 +21,12 @@ class IAMPolicyBuilderTest(unittest.TestCase):
 
     def test_base_policy_present(self):
         """Tests the path is correct."""
-        finder = create_autospec(
-            IAMPolicyFinder,
-            find=Mock(return_value=[])
-        )
+        finder = create_autospec(IAMPolicyFinder, find=Mock(return_value=[]))
         builder = IAMPolicyBuilder(finder)
-        policies = builder.build('my_test')
+        policies = builder.build("my_test")
         self.assertEqual(len(policies), 1)
-        self.assertEqual(policies[0].PolicyName, 'base-policy')
+        self.assertEqual(policies[0].PolicyName, "base-policy")
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
