@@ -14,7 +14,7 @@ if sys.version_info.major > 2:
 else:
     from pathlib2 import Path  # pylint: disable=E
 
-LOGGER = logging.getLogger(__name__.replace('._', '.'))
+LOGGER = logging.getLogger(__name__.replace("._", "."))
 RUNWAY_YML = """---
 # See full syntax at https://docs.onica.com/projects/runway/en/latest/
 deployments:
@@ -27,7 +27,7 @@ deployments:
 """
 
 
-@click.command('init', short_help='create runway.yml')
+@click.command("init", short_help="create runway.yml")
 @options.debug
 @options.no_color
 @options.verbose
@@ -35,18 +35,19 @@ deployments:
 def init(ctx, **_):
     # type: (click.Context, Any) -> None
     """Create an example runway.yml file in the currect directory."""
-    runway_yml = Path.cwd() / 'runway.yml'
+    runway_yml = Path.cwd() / "runway.yml"
 
-    LOGGER.verbose('checking for preexisting runway.yml file...')
+    LOGGER.verbose("checking for preexisting runway.yml file...")
     if runway_yml.is_file():
-        LOGGER.error('There is already a %s file in the current directory',
-                     runway_yml.name)
+        LOGGER.error(
+            "There is already a %s file in the current directory", runway_yml.name
+        )
         ctx.exit(1)
 
     # TODO remove use of six when dropping python 2
     runway_yml.write_text(six.u(RUNWAY_YML))
-    LOGGER.success('runway.yml generated')
+    LOGGER.success("runway.yml generated")
     LOGGER.notice(
-        'See addition getting started information at '
-        'https://docs.onica.com/projects/runway/en/latest/getting_started.html'
+        "See addition getting started information at "
+        "https://docs.onica.com/projects/runway/en/latest/getting_started.html"
     )
