@@ -3,8 +3,4 @@ from ._account import AccountDetails
 from ._assume_role import AssumeRole
 from ._cli import cli
 
-__all__ = [
-    'AccountDetails',
-    'AssumeRole',
-    'cli'
-]
+__all__ = ["AccountDetails", "AssumeRole", "cli"]
