@@ -34,9 +34,8 @@ from ..factories import MockProviderBuilder, MockThreadingEvent
 def mock_stack_parameters(parameters):
     """Mock stack parameters."""
     return {
-        'Parameters': [
-            {'ParameterKey': k, 'ParameterValue': v}
-            for k, v in parameters.items()
+        "Parameters": [
+            {"ParameterKey": k, "ParameterValue": v} for k, v in parameters.items()
         ]
     }
 
@@ -46,7 +45,7 @@ class MockProvider(BaseProvider):
 
     def __init__(self, *args, **kwargs):
         """Instantiate class."""
-        self._outputs = kwargs.get('outputs', {})
+        self._outputs = kwargs.get("outputs", {})
 
     def set_outputs(self, outputs):
         """Set outputs."""
@@ -72,8 +71,8 @@ class TestBuildAction(unittest.TestCase):
         self.context = Context(config=Config({"namespace": "namespace"}))
         self.provider = MockProvider()
         self.build_action = build.Action(
-            self.context,
-            provider_builder=MockProviderBuilder(self.provider))
+            self.context, provider_builder=MockProviderBuilder(self.provider)
+        )
 
     def _get_context(self, extra_config_args=None, **kwargs):
         """Get context."""
@@ -81,36 +80,33 @@ class TestBuildAction(unittest.TestCase):
             "namespace": "namespace",
             "stacks": [
                 {"name": "vpc"},
-                {
-                    "name": "bastion",
-                    "variables": {
-                        "test": "${output vpc::something}"
-                    }
-                },
+                {"name": "bastion", "variables": {"test": "${output vpc::something}"}},
                 {
                     "name": "db",
                     "variables": {
                         "test": "${output vpc::something}",
-                        "else": "${output bastion::something}"
-                    }
+                        "else": "${output bastion::something}",
+                    },
                 },
-                {"name": "other", "variables": {}}
+                {"name": "other", "variables": {}},
             ],
         }
         if extra_config_args:
             config.update(extra_config_args)
         return Context(config=Config(config), **kwargs)
 
-    @patch('runway.cfngin.context.Context._persistent_graph_tags',
-           new_callable=PropertyMock)
+    @patch(
+        "runway.cfngin.context.Context._persistent_graph_tags",
+        new_callable=PropertyMock,
+    )
     def test_generate_plan_persist_destroy(self, mock_graph_tags):
         """Test generate plan persist destroy."""
         mock_graph_tags.return_value = {}
         context = self._get_context(
-            extra_config_args={'persistent_graph_key': 'test.json'}
+            extra_config_args={"persistent_graph_key": "test.json"}
         )
         context._persistent_graph = Graph.from_steps(
-            [Step.from_stack_name('removed', context)]
+            [Step.from_stack_name("removed", context)]
         )
         build_action = build.Action(context=context)
         plan = build_action._Action__generate_plan()
@@ -121,38 +117,31 @@ class TestBuildAction(unittest.TestCase):
         # order is different between python2/3 so can't compare dicts
         result_graph_dict = plan.graph.to_dict()
         self.assertEqual(5, len(result_graph_dict))
-        self.assertEqual(set(), result_graph_dict['other'])
-        self.assertEqual(set(), result_graph_dict['removed'])
-        self.assertEqual(set(), result_graph_dict['vpc'])
-        self.assertEqual(set(['vpc']), result_graph_dict['bastion'])
-        self.assertEqual(set(['bastion', 'vpc']), result_graph_dict['db'])
-        self.assertEqual(build_action._destroy_stack,
-                         plan.graph.steps['removed'].fn)
-        self.assertEqual(build_action._launch_stack,
-                         plan.graph.steps['vpc'].fn)
-        self.assertEqual(build_action._launch_stack,
-                         plan.graph.steps['bastion'].fn)
-        self.assertEqual(build_action._launch_stack,
-                         plan.graph.steps['db'].fn)
-        self.assertEqual(build_action._launch_stack,
-                         plan.graph.steps['other'].fn)
+        self.assertEqual(set(), result_graph_dict["other"])
+        self.assertEqual(set(), result_graph_dict["removed"])
+        self.assertEqual(set(), result_graph_dict["vpc"])
+        self.assertEqual(set(["vpc"]), result_graph_dict["bastion"])
+        self.assertEqual(set(["bastion", "vpc"]), result_graph_dict["db"])
+        self.assertEqual(build_action._destroy_stack, plan.graph.steps["removed"].fn)
+        self.assertEqual(build_action._launch_stack, plan.graph.steps["vpc"].fn)
+        self.assertEqual(build_action._launch_stack, plan.graph.steps["bastion"].fn)
+        self.assertEqual(build_action._launch_stack, plan.graph.steps["db"].fn)
+        self.assertEqual(build_action._launch_stack, plan.graph.steps["other"].fn)
 
     def test_handle_missing_params(self):
         """Test handle missing params."""
-        existing_stack_param_dict = {
-            "StackName": "teststack",
-            "Address": "192.168.0.1"
-        }
-        existing_stack_params = mock_stack_parameters(
-            existing_stack_param_dict
-        )
+        existing_stack_param_dict = {"StackName": "teststack", "Address": "192.168.0.1"}
+        existing_stack_params = mock_stack_parameters(existing_stack_param_dict)
         all_params = existing_stack_param_dict.keys()
         required = ["Address"]
         parameter_values = {"Address": "192.168.0.1"}
-        expected_params = {"StackName": UsePreviousParameterValue,
-                           "Address": "192.168.0.1"}
-        result = _handle_missing_parameters(parameter_values, all_params,
-                                            required, existing_stack_params)
+        expected_params = {
+            "StackName": UsePreviousParameterValue,
+            "Address": "192.168.0.1",
+        }
+        result = _handle_missing_parameters(
+            parameter_values, all_params, required, existing_stack_params
+        )
         self.assertEqual(sorted(result), sorted(list(expected_params.items())))
 
     def test_missing_params_no_existing_stack(self):
@@ -167,22 +156,15 @@ class TestBuildAction(unittest.TestCase):
 
     def test_existing_stack_params_does_not_override_given_params(self):
         """Test existing stack params does not override given params."""
-        existing_stack_param_dict = {
-            "StackName": "teststack",
-            "Address": "192.168.0.1"
-        }
-        existing_stack_params = mock_stack_parameters(
-            existing_stack_param_dict
-        )
+        existing_stack_param_dict = {"StackName": "teststack", "Address": "192.168.0.1"}
+        existing_stack_params = mock_stack_parameters(existing_stack_param_dict)
         all_params = existing_stack_param_dict.keys()
         required = ["Address"]
         parameter_values = {"Address": "10.0.0.1"}
-        result = _handle_missing_parameters(parameter_values, all_params,
-                                            required, existing_stack_params)
-        self.assertEqual(
-            sorted(result),
-            sorted(list(parameter_values.items()))
+        result = _handle_missing_parameters(
+            parameter_values, all_params, required, existing_stack_params
         )
+        self.assertEqual(sorted(result), sorted(list(parameter_values.items())))
 
     def test_generate_plan(self):
         """Test generate plan."""
@@ -191,19 +173,19 @@ class TestBuildAction(unittest.TestCase):
         plan = build_action._Action__generate_plan()
         self.assertEqual(
             {
-                'db': set(['bastion', 'vpc']),
-                'bastion': set(['vpc']),
-                'other': set([]),
-                'vpc': set([])},
-            plan.graph.to_dict()
+                "db": set(["bastion", "vpc"]),
+                "bastion": set(["vpc"]),
+                "other": set([]),
+                "vpc": set([]),
+            },
+            plan.graph.to_dict(),
         )
 
     def test_does_not_execute_plan_when_outline_specified(self):
         """Test does not execute plan when outline specified."""
         context = self._get_context()
         build_action = build.Action(context, cancel=MockThreadingEvent())
-        with patch.object(build_action, "_generate_plan") as \
-                mock_generate_plan:
+        with patch.object(build_action, "_generate_plan") as mock_generate_plan:
             build_action.run(outline=True)
             self.assertEqual(mock_generate_plan().execute.call_count, 0)
 
@@ -211,27 +193,29 @@ class TestBuildAction(unittest.TestCase):
         """Test execute plan when outline not specified."""
         context = self._get_context()
         build_action = build.Action(context, cancel=MockThreadingEvent())
-        with patch.object(build_action, "_generate_plan") as \
-                mock_generate_plan:
+        with patch.object(build_action, "_generate_plan") as mock_generate_plan:
             build_action.run(outline=False)
             self.assertEqual(mock_generate_plan().execute.call_count, 1)
 
-    @patch('runway.cfngin.context.Context._persistent_graph_tags',
-           new_callable=PropertyMock)
-    @patch('runway.cfngin.context.Context.lock_persistent_graph',
-           new_callable=MagicMock)
-    @patch('runway.cfngin.context.Context.unlock_persistent_graph',
-           new_callable=MagicMock)
-    @patch('runway.cfngin.plan.Plan.execute', new_callable=MagicMock)
-    def test_run_persist(self, mock_execute, mock_unlock, mock_lock,
-                         mock_graph_tags):
+    @patch(
+        "runway.cfngin.context.Context._persistent_graph_tags",
+        new_callable=PropertyMock,
+    )
+    @patch(
+        "runway.cfngin.context.Context.lock_persistent_graph", new_callable=MagicMock
+    )
+    @patch(
+        "runway.cfngin.context.Context.unlock_persistent_graph", new_callable=MagicMock
+    )
+    @patch("runway.cfngin.plan.Plan.execute", new_callable=MagicMock)
+    def test_run_persist(self, mock_execute, mock_unlock, mock_lock, mock_graph_tags):
         """Test run persist."""
         mock_graph_tags.return_value = {}
         context = self._get_context(
-            extra_config_args={'persistent_graph_key': 'test.json'}
+            extra_config_args={"persistent_graph_key": "test.json"}
         )
         context._persistent_graph = Graph.from_steps(
-            [Step.from_stack_name('removed', context)]
+            [Step.from_stack_name("removed", context)]
         )
         build_action = build.Action(context=context)
         build_action.run()
@@ -243,13 +227,12 @@ class TestBuildAction(unittest.TestCase):
 
     def test_should_update(self):
         """Test should update."""
-        test_scenario = namedtuple("test_scenario",
-                                   ["locked", "force", "result"])
+        test_scenario = namedtuple("test_scenario", ["locked", "force", "result"])
         test_scenarios = (
             test_scenario(locked=False, force=False, result=True),
             test_scenario(locked=False, force=True, result=True),
             test_scenario(locked=True, force=False, result=False),
-            test_scenario(locked=True, force=True, result=True)
+            test_scenario(locked=True, force=True, result=True),
         )
         mock_stack = MagicMock(["locked", "force", "name"])
         mock_stack.name = "test-stack"
@@ -265,7 +248,7 @@ class TestBuildAction(unittest.TestCase):
             {"outline": True, "dump": False, "result": False},
             {"outline": False, "dump": True, "result": False},
             {"outline": True, "dump": True, "result": False},
-            {"outline": True, "dump": "DUMP", "result": False}
+            {"outline": True, "dump": "DUMP", "result": False},
         ]
 
         for scenario in test_scenarios:
@@ -273,16 +256,14 @@ class TestBuildAction(unittest.TestCase):
             dump = scenario["dump"]
             result = scenario["result"]
             try:
-                self.assertEqual(
-                    build.should_ensure_cfn_bucket(outline, dump), result)
+                self.assertEqual(build.should_ensure_cfn_bucket(outline, dump), result)
             except AssertionError as err:
                 err.args += ("scenario", str(scenario))
                 raise
 
     def test_should_submit(self):
         """Test should submit."""
-        test_scenario = namedtuple("test_scenario",
-                                   ["enabled", "result"])
+        test_scenario = namedtuple("test_scenario", ["enabled", "result"])
         test_scenarios = (
             test_scenario(enabled=False, result=False),
             test_scenario(enabled=True, result=True),
@@ -302,18 +283,17 @@ class TestLaunchStack(TestBuildAction):
         """Run before tests."""
         self.context = self._get_context()
         self.session = get_session(region=None)
-        self.provider = Provider(self.session, interactive=False,
-                                 recreate_failed=False)
+        self.provider = Provider(self.session, interactive=False, recreate_failed=False)
         provider_builder = MockProviderBuilder(self.provider)
-        self.build_action = build.Action(self.context,
-                                         provider_builder=provider_builder,
-                                         cancel=MockThreadingEvent())
+        self.build_action = build.Action(
+            self.context, provider_builder=provider_builder, cancel=MockThreadingEvent()
+        )
 
         self.stack = MagicMock()
         self.stack.region = None
-        self.stack.name = 'vpc'
-        self.stack.fqn = 'vpc'
-        self.stack.blueprint.rendered = '{}'
+        self.stack.name = "vpc"
+        self.stack.fqn = "vpc"
+        self.stack.blueprint.rendered = "{}"
         self.stack.locked = False
         self.stack_status = None
 
@@ -330,20 +310,26 @@ class TestLaunchStack(TestBuildAction):
             if name != self.stack.name or not self.stack_status:
                 raise StackDoesNotExist(name)
 
-            return {'StackName': self.stack.name,
-                    'StackStatus': self.stack_status,
-                    'Outputs': [],
-                    'Tags': []}
+            return {
+                "StackName": self.stack.name,
+                "StackStatus": self.stack_status,
+                "Outputs": [],
+                "Tags": [],
+            }
 
         def get_events(name, *args, **kwargs):
-            return [{'ResourceStatus': 'ROLLBACK_IN_PROGRESS',
-                     'ResourceStatusReason': 'CFN fail'}]
+            return [
+                {
+                    "ResourceStatus": "ROLLBACK_IN_PROGRESS",
+                    "ResourceStatusReason": "CFN fail",
+                }
+            ]
 
-        patch_object(self.provider, 'get_stack', side_effect=get_stack)
-        patch_object(self.provider, 'update_stack')
-        patch_object(self.provider, 'create_stack')
-        patch_object(self.provider, 'destroy_stack')
-        patch_object(self.provider, 'get_events', side_effect=get_events)
+        patch_object(self.provider, "get_stack", side_effect=get_stack)
+        patch_object(self.provider, "update_stack")
+        patch_object(self.provider, "create_stack")
+        patch_object(self.provider, "destroy_stack")
+        patch_object(self.provider, "get_events", side_effect=get_events)
 
         patch_object(self.build_action, "s3_stack_push")
 
@@ -370,10 +356,10 @@ class TestLaunchStack(TestBuildAction):
         self._advance(None, SUBMITTED, "creating new stack")
 
         # status should stay as SUBMITTED when the stack becomes available
-        self._advance('CREATE_IN_PROGRESS', SUBMITTED, "creating new stack")
+        self._advance("CREATE_IN_PROGRESS", SUBMITTED, "creating new stack")
 
         # status should become COMPLETE once the stack finishes
-        self._advance('CREATE_COMPLETE', COMPLETE, "creating new stack")
+        self._advance("CREATE_COMPLETE", COMPLETE, "creating new stack")
 
     def test_launch_stack_create_rollback(self):
         """Test launch stack create rollback."""
@@ -384,47 +370,43 @@ class TestLaunchStack(TestBuildAction):
         self._advance(None, SUBMITTED, "creating new stack")
 
         # provider should now return the CF stack since it exists
-        self._advance("CREATE_IN_PROGRESS", SUBMITTED,
-                      "creating new stack")
+        self._advance("CREATE_IN_PROGRESS", SUBMITTED, "creating new stack")
 
         # rollback should be noticed
-        self._advance("ROLLBACK_IN_PROGRESS", SUBMITTED,
-                      "rolling back new stack")
+        self._advance("ROLLBACK_IN_PROGRESS", SUBMITTED, "rolling back new stack")
 
         # rollback should not be added twice to the reason
-        self._advance("ROLLBACK_IN_PROGRESS", SUBMITTED,
-                      "rolling back new stack")
+        self._advance("ROLLBACK_IN_PROGRESS", SUBMITTED, "rolling back new stack")
 
         # rollback should finish with failure
-        self._advance("ROLLBACK_COMPLETE", FAILED,
-                      "rolled back new stack")
+        self._advance("ROLLBACK_COMPLETE", FAILED, "rolled back new stack")
 
     def test_launch_stack_recreate(self):
         """Test launch stack recreate."""
-        self.provider.recreate_failed = True  # pylint: disable=attribute-defined-outside-init
+        # pylint: disable=attribute-defined-outside-init
+        self.provider.recreate_failed = True
 
         # initial status should be PENDING
         self.assertEqual(self.step.status, PENDING)
 
         # first action with an existing failed stack should be deleting it
-        self._advance("ROLLBACK_COMPLETE", SUBMITTED,
-                      "destroying stack for re-creation")
+        self._advance(
+            "ROLLBACK_COMPLETE", SUBMITTED, "destroying stack for re-creation"
+        )
 
         # status should stay as submitted during deletion
-        self._advance("DELETE_IN_PROGRESS", SUBMITTED,
-                      "destroying stack for re-creation")
+        self._advance(
+            "DELETE_IN_PROGRESS", SUBMITTED, "destroying stack for re-creation"
+        )
 
         # deletion being complete must trigger re-creation
-        self._advance("DELETE_COMPLETE", SUBMITTED,
-                      "re-creating stack")
+        self._advance("DELETE_COMPLETE", SUBMITTED, "re-creating stack")
 
         # re-creation should continue as SUBMITTED
-        self._advance("CREATE_IN_PROGRESS", SUBMITTED,
-                      "re-creating stack")
+        self._advance("CREATE_IN_PROGRESS", SUBMITTED, "re-creating stack")
 
         # re-creation should finish with success
-        self._advance("CREATE_COMPLETE", COMPLETE,
-                      "re-creating stack")
+        self._advance("CREATE_COMPLETE", COMPLETE, "re-creating stack")
 
     def test_launch_stack_update_skipped(self):
         """Test launch stack update skipped."""
@@ -433,8 +415,7 @@ class TestLaunchStack(TestBuildAction):
 
         # start the upgrade, that will be skipped
         self.provider.update_stack.side_effect = StackDidNotChange
-        self._advance("CREATE_COMPLETE", SKIPPED,
-                      "nochange")
+        self._advance("CREATE_COMPLETE", SKIPPED, "nochange")
 
     def test_launch_stack_update_rollback(self):
         """Test launch stack update rollback."""
@@ -442,20 +423,16 @@ class TestLaunchStack(TestBuildAction):
         self.assertEqual(self.step.status, PENDING)
 
         # initial run should return SUBMITTED since we've passed off to CF
-        self._advance("CREATE_COMPLETE", SUBMITTED,
-                      "updating existing stack")
+        self._advance("CREATE_COMPLETE", SUBMITTED, "updating existing stack")
 
         # update should continue as SUBMITTED
-        self._advance("UPDATE_IN_PROGRESS", SUBMITTED,
-                      "updating existing stack")
+        self._advance("UPDATE_IN_PROGRESS", SUBMITTED, "updating existing stack")
 
         # rollback should be noticed
-        self._advance("UPDATE_ROLLBACK_IN_PROGRESS", SUBMITTED,
-                      "rolling back update")
+        self._advance("UPDATE_ROLLBACK_IN_PROGRESS", SUBMITTED, "rolling back update")
 
         # rollback should finish with failure
-        self._advance("UPDATE_ROLLBACK_COMPLETE", FAILED,
-                      "rolled back update")
+        self._advance("UPDATE_ROLLBACK_COMPLETE", FAILED, "rolled back update")
 
     def test_launch_stack_update_success(self):
         """Test launch stack update success."""
@@ -463,16 +440,13 @@ class TestLaunchStack(TestBuildAction):
         self.assertEqual(self.step.status, PENDING)
 
         # initial run should return SUBMITTED since we've passed off to CF
-        self._advance("CREATE_COMPLETE", SUBMITTED,
-                      "updating existing stack")
+        self._advance("CREATE_COMPLETE", SUBMITTED, "updating existing stack")
 
         # update should continue as SUBMITTED
-        self._advance("UPDATE_IN_PROGRESS", SUBMITTED,
-                      "updating existing stack")
+        self._advance("UPDATE_IN_PROGRESS", SUBMITTED, "updating existing stack")
 
         # update should finish with success
-        self._advance("UPDATE_COMPLETE", COMPLETE,
-                      "updating existing stack")
+        self._advance("UPDATE_COMPLETE", COMPLETE, "updating existing stack")
 
 
 class TestFunctions(unittest.TestCase):
@@ -487,12 +461,8 @@ class TestFunctions(unittest.TestCase):
     def test_resolve_parameters_unused_parameter(self):
         """Test resolve parameters unused parameter."""
         self.blueprint.get_parameter_definitions.return_value = {
-            "a": {
-                "type": CFNString,
-                "description": "A"},
-            "b": {
-                "type": CFNString,
-                "description": "B"}
+            "a": {"type": CFNString, "description": "A"},
+            "b": {"type": CFNString, "description": "B"},
         }
         params = {"a": "Apple", "c": "Carrot"}
         resolved_params = _resolve_parameters(params, self.blueprint)
@@ -502,12 +472,8 @@ class TestFunctions(unittest.TestCase):
     def test_resolve_parameters_none_conversion(self):
         """Test resolve parameters none conversion."""
         self.blueprint.get_parameter_definitions.return_value = {
-            "a": {
-                "type": CFNString,
-                "description": "A"},
-            "b": {
-                "type": CFNString,
-                "description": "B"}
+            "a": {"type": CFNString, "description": "A"},
+            "b": {"type": CFNString, "description": "B"},
         }
         params = {"a": None, "c": "Carrot"}
         resolved_params = _resolve_parameters(params, self.blueprint)
@@ -516,12 +482,8 @@ class TestFunctions(unittest.TestCase):
     def test_resolve_parameters_booleans(self):
         """Test resolve parameters booleans."""
         self.blueprint.get_parameter_definitions.return_value = {
-            "a": {
-                "type": CFNString,
-                "description": "A"},
-            "b": {
-                "type": CFNString,
-                "description": "B"},
+            "a": {"type": CFNString, "description": "A"},
+            "b": {"type": CFNString, "description": "B"},
         }
         params = {"a": True, "b": False}
         resolved_params = _resolve_parameters(params, self.blueprint)
