@@ -35,7 +35,7 @@ def pytest_ignore_collect(path, config):  # pylint: disable=unused-argument
     return config.option.integration_only
 
 
-@pytest.fixture(scope='session', autouse=True)
+@pytest.fixture(scope="session", autouse=True)
 def aws_credentials():
     # type: () -> Dict[str, str]
     """Handle change in https://github.com/spulec/moto/issues/1924.
@@ -45,20 +45,20 @@ def aws_credentials():
 
     """
     overrides = {
-        'AWS_ACCESS_KEY_ID': 'testing',
-        'AWS_SECRET_ACCESS_KEY': 'testing',
-        'AWS_DEFAULT_REGION': 'us-east-1'
+        "AWS_ACCESS_KEY_ID": "testing",
+        "AWS_SECRET_ACCESS_KEY": "testing",
+        "AWS_DEFAULT_REGION": "us-east-1",
     }
     saved_env = {}
     for key, value in overrides.items():
-        LOG.info('Overriding env var: %s=%s', key, value)
+        LOG.info("Overriding env var: %s=%s", key, value)
         saved_env[key] = os.environ.get(key, None)
         os.environ[key] = value
 
     yield
 
     for key, value in saved_env.items():
-        LOG.info('Restoring saved env var: %s=%s', key, value)
+        LOG.info("Restoring saved env var: %s=%s", key, value)
         if value is None:
             os.environ.pop(key, None)  # handle key missing
         else:
@@ -67,29 +67,28 @@ def aws_credentials():
     saved_env.clear()
 
 
-@pytest.fixture(scope='package')
+@pytest.fixture(scope="package")
 def fixture_dir():
     # type: () -> str
     """Path to the fixture directory."""
-    return os.path.join(os.path.dirname(os.path.realpath(__file__)),
-                        'fixtures')
+    return os.path.join(os.path.dirname(os.path.realpath(__file__)), "fixtures")
 
 
-@pytest.fixture(scope='module')
+@pytest.fixture(scope="module")
 def fx_config():
     """Return YAML loader for config fixtures."""
-    return YamlLoader(TEST_ROOT.parent / 'fixtures' / 'configs',
-                      load_class=Config,
-                      load_type='kwargs')
+    return YamlLoader(
+        TEST_ROOT.parent / "fixtures" / "configs", load_class=Config, load_type="kwargs"
+    )
 
 
-@pytest.fixture(scope='function')
+@pytest.fixture(scope="function")
 def fx_deployments():
     """Return YAML loader for deployment fixtures."""
-    return YamlLoaderDeploymet(TEST_ROOT / 'fixtures' / 'deployments')
+    return YamlLoaderDeploymet(TEST_ROOT / "fixtures" / "deployments")
 
 
-@pytest.fixture(scope='module')
+@pytest.fixture(scope="module")
 def yaml_fixtures(request, fixture_dir):
     """Load test fixture yaml files.
 
@@ -97,7 +96,7 @@ def yaml_fixtures(request, fixture_dir):
     `YAML_FIXTURES` variable of the module.
 
     """
-    file_paths = getattr(request.module, 'YAML_FIXTURES', [])
+    file_paths = getattr(request.module, "YAML_FIXTURES", [])
     result = {}
     for file_path in file_paths:
         with open(os.path.join(fixture_dir, file_path)) as _file:
@@ -106,62 +105,65 @@ def yaml_fixtures(request, fixture_dir):
     return result
 
 
-@pytest.fixture(scope='function')
+@pytest.fixture(scope="function")
 def cfngin_context(runway_context):
     """Create a mock CFNgin context object."""
-    return MockCFNginContext(environment={},
-                             boto3_credentials=runway_context.boto3_credentials,
-                             region=runway_context.env_region)
+    return MockCFNginContext(
+        environment={},
+        boto3_credentials=runway_context.boto3_credentials,
+        region=runway_context.env_region,
+    )
 
 
 @pytest.fixture
 def patch_time(monkeypatch):
     """Patch built-in time object."""
-    monkeypatch.setattr('time.sleep', lambda s: None)
+    monkeypatch.setattr("time.sleep", lambda s: None)
 
 
 @pytest.fixture
 def platform_darwin(monkeypatch):
     """Patch platform.system to always return "Darwin"."""
-    monkeypatch.setattr('platform.system', lambda: 'Darwin')
+    monkeypatch.setattr("platform.system", lambda: "Darwin")
 
 
 @pytest.fixture
 def platform_windows(monkeypatch):
     """Patch platform.system to always return "Windows"."""
-    monkeypatch.setattr('platform.system', lambda: 'Windows')
+    monkeypatch.setattr("platform.system", lambda: "Windows")
 
 
-@pytest.fixture(scope='function')
+@pytest.fixture(scope="function")
 def patch_runway_config(request, monkeypatch, runway_config):
     """Patch Runway config and return a mock config object."""
-    patch_path = getattr(request.module, 'PATCH_RUNWAY_CONFIG', None)
+    patch_path = getattr(request.module, "PATCH_RUNWAY_CONFIG", None)
     if patch_path:
         monkeypatch.setattr(patch_path, runway_config)
     return runway_config
 
 
-@pytest.fixture(scope='function')
+@pytest.fixture(scope="function")
 def runway_config():
     """Create a mock runway config object."""
     return MockRunwayConfig()
 
 
-@pytest.fixture(scope='function')
+@pytest.fixture(scope="function")
 def runway_context(request):
     """Create a mock Runway context object."""
     env_vars = {
-        'AWS_REGION': getattr(request.module, 'AWS_REGION', 'us-east-1'),
-        'DEFAULT_AWS_REGION': getattr(request.module, 'AWS_REGION', 'us-east-1'),
-        'DEPLOY_ENVIRONMENT': getattr(request.module, 'DEPLOY_ENVIRONMENT', 'test')
+        "AWS_REGION": getattr(request.module, "AWS_REGION", "us-east-1"),
+        "DEFAULT_AWS_REGION": getattr(request.module, "AWS_REGION", "us-east-1"),
+        "DEPLOY_ENVIRONMENT": getattr(request.module, "DEPLOY_ENVIRONMENT", "test"),
     }
     creds = {
-        'AWS_ACCESS_KEY_ID': 'test_access_key',
-        'AWS_SECRET_ACCESS_KEY': 'test_secret_key',
-        'AWS_SESSION_TOKEN': 'test_session_token'
+        "AWS_ACCESS_KEY_ID": "test_access_key",
+        "AWS_SECRET_ACCESS_KEY": "test_secret_key",
+        "AWS_SESSION_TOKEN": "test_session_token",
     }
-    env_vars.update(getattr(request.module, 'AWS_CREDENTIALS', creds))
-    env_vars.update(getattr(request.module, 'ENV_VARS', {}))
-    return MockRunwayContext(command='test',
-                             deploy_environment=DeployEnvironment(environ=env_vars,
-                                                                  explicit_name='test'))
+    env_vars.update(getattr(request.module, "AWS_CREDENTIALS", creds))
+    env_vars.update(getattr(request.module, "ENV_VARS", {}))
+    return MockRunwayContext(
+        command="test",
+        deploy_environment=DeployEnvironment(environ=env_vars, explicit_name="test"),
+    )
